<?php

/**
 * 对非管理员用户隐藏提醒
 */
add_action( 'admin_head', function () {
	if ( ! current_user_can( 'update_core' ) ) {
		remove_action( 'admin_notices', 'update_nag', 3 );
		remove_action( 'network_admin_notices', 'update_nag', 3 );
	}
}, 1 );


/**
 * 替换头像源代为多说
 */
add_filter( 'get_avatar', function ( $avatar ) {
	$avatar = str_replace( [ "www.gravatar.com", "0.gravatar.com", "1.gravatar.com", "2.gravatar.com" ], "secure.gravatar.com", $avatar );
	$avatar = str_replace( "http://", "https://", $avatar );

	return $avatar;
} );


/**
 * 文章最多保存 5 个版本
 */
if ( ! defined( 'WP_POST_REVISIONS' ) ) {
	define( 'WP_POST_REVISIONS', 5 );
}


/**
 * 自动设置图像链接为 none
 */
add_action( 'admin_init', function () {
	$image_set = get_option( 'image_default_link_type' );
	if ( $image_set !== 'none' ) {
		update_option( 'image_default_link_type', 'none' );
	}
}, 10 );


/**
 * 中文图片名自动命名
 */
add_filter( 'sanitize_file_name', function ( $filename ) {
	$parts     = explode( '.', $filename );
	$filename  = array_shift( $parts );
	$extension = array_pop( $parts );
	foreach ( (array) $parts as $part ) {
		$filename .= '.' . $part;
	}

	if ( preg_match( '/[\x{4e00}-\x{9fa5}]+/u', $filename ) ) {
		$filename = date( 'md' ) . wizhi_rand_str( 8 );
	}
	$filename .= '.' . $extension;

	return $filename;
}, 5, 1 );


/**
 * 自动添加未命名标题
 */
add_filter( 'the_title', function ( $title ) {
	if ( $title == '' ) {
		return 'Untitled';
	} else {
		return $title;
	}
} );


/**
 * 保存文章时，自动添加特色图像
 */
add_action( 'save_post', function ( $post_id ) {

	if ( wp_is_post_revision( $post_id ) ) {
		return null;
	}

	if ( ! isset( $post_id ) ) {
		return null;
	}

	if ( has_post_thumbnail( $post_id ) ) {
		return null;
	}

	$args = [
		'numberposts'    => 1,
		'order'          => 'DESC', // DESC for the last image
		'post_mime_type' => 'image',
		'post_parent'    => $post_id,
		'post_status'    => null,
		'post_type'      => 'attachment',
	];

	$attached_image = get_children( $args );
	if ( $attached_image ) {
		foreach ( $attached_image as $attachment_id => $attachment ) {
			set_post_thumbnail( $post_id, $attachment_id );
		}
	}

} );


/**
 * 选中的分类显示在顶部
 */
if ( ! class_exists( 'wizhi_cat_check_order' ) ) {

	class wizhi_cat_check_order {

		function __construct() {

			function changeTaxonomyCheckboxlistOrder( $args, $post_id ) {
				if ( isset( $args[ 'taxonomy' ] ) ) {
					$args[ 'checked_ontop' ] = false;
				}

				return $args;
			}

			add_filter( 'wp_terms_checklist_args', 'changeTaxonomyCheckboxlistOrder', 10, 2 );
		}

	}

	$fttaxonomychangeorder = new wizhi_cat_check_order();

}


/**
 * 添加浏览器到 body class 上
 */
add_filter( 'body_class', function ( $classes ) {
	global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;

	if ( $is_lynx ) {
		$classes[] = 'lynx';
	} elseif ( $is_gecko ) {
		$classes[] = 'gecko';
	} elseif ( $is_opera ) {
		$classes[] = 'opera';
	} elseif ( $is_NS4 ) {
		$classes[] = 'ns4';
	} elseif ( $is_safari ) {
		$classes[] = 'safari';
	} elseif ( $is_chrome ) {
		$classes[] = 'chrome';
	} elseif ( $is_IE ) {
		$browser = $_SERVER[ 'HTTP_USER_AGENT' ];
		$browser = substr( "$browser", 25, 8 );
		if ( $browser == "MSIE 7.0" ) {
			$classes[] = 'ie7';
			$classes[] = 'ie';
		} elseif ( $browser == "MSIE 6.0" ) {
			$classes[] = 'ie6';
			$classes[] = 'ie';
		} elseif ( $browser == "MSIE 8.0" ) {
			$classes[] = 'ie8';
			$classes[] = 'ie';
		} elseif ( $browser == "MSIE 9.0" ) {
			$classes[] = 'ie9';
			$classes[] = 'ie';
		} else {
			$classes[] = 'ie';
		}
	} else {
		$classes[] = 'unknown';
	}

	if ( $is_iphone ) {
		$classes[] = 'iphone';
	}

	return $classes;
} );
